# coding=utf-8
__all__ = [
    'api',
    'api_ids',
    'api_rids',
    'attachments_api',
    'authentication_api',
    'authorization',
    'comments_api',
    'connect_download',
    'datasource',
    'datasource_api',
    'datasource_logset',
    'datasource_logset_api',
    'datasource_pagination_api',
    'event',
    'ingest_api',
    'ingest_manifest',
    'ingest_workflow_api',
    'module',
    'module_internal',
    'modules_api',
    'persistent_compute_api',
    'scout',
    'scout_api',
    'scout_asset_api',
    'scout_assets',
    'scout_catalog',
    'scout_channelvariables_api',
    'scout_chart_api',
    'scout_chartdefinition_api',
    'scout_checklistexecution_api',
    'scout_checks_api',
    'scout_comparisonnotebook_api',
    'scout_comparisonrun_api',
    'scout_compute_api',
    'scout_compute_api_deprecated',
    'scout_compute_resolved_api',
    'scout_dataexport_api',
    'scout_datareview_api',
    'scout_datasource',
    'scout_datasource_connection',
    'scout_datasource_connection_api',
    'scout_datasource_connection_api_influx',
    'scout_favorites',
    'scout_favorites_api',
    'scout_integrations_api',
    'scout_internal_search_api',
    'scout_jobs_api',
    'scout_layout_api',
    'scout_metadata',
    'scout_notebook_api',
    'scout_plotting',
    'scout_rids_api',
    'scout_run_api',
    'scout_savedviews',
    'scout_savedviews_api',
    'scout_template_api',
    'scout_units_api',
    'scout_versioning_api',
    'scout_video',
    'scout_video_api',
    'scout_workbookcommon_api',
    'secrets_api',
    'security_api_workspace',
    'storage_datasource_api',
    'storage_deletion_api',
    'storage_series_api',
    'storage_writer_api',
    'themes_api',
    'timeseries_channelmetadata',
    'timeseries_channelmetadata_api',
    'timeseries_logicalseries',
    'timeseries_logicalseries_api',
    'timeseries_metadata',
    'timeseries_metadata_api',
    'timeseries_seriescache',
    'timeseries_seriescache_api',
    'upload_api',
    'usercreation_api',
]

__conjure_generator_version__ = "4.17.0"

__version__ = "0.956.0"

